<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN চালু</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN বন্ধ</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>ক্যাপ্স লোক চালু</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>ক্যাপ্স লোক বন্ধ</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>সংখ্যাক্রমিক কুপারি চালু</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>সংখ্যাক্রমিক কুপারি বন্ধ</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>টাচপ্যাড চালু</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>টাচপ্যাড বন্ধ</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>টাচপ্যাড ফ্লিপ</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn ফ্লিপ</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>এয়ারপ্লেন মোড চালু</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>এয়ারপ্লেন মোড বন্ধ</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>পরিষ্কার শক্তি</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>শক্তি সংরক্ষক</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>উচ্চ পরিপ্রেক্ষিতা</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>বিংগো ফেরতিই চালু</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>বিংগো ফেরতিই বন্ধ</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>বিংগো ফেরতিই চালু করতে ব্যর্থ হয়েছে</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>